# Lista de Tradutores do EXOTIC

*Para traduzir este documento para o português do Brasil, foi necessária a ajuda de membros voluntários, dedicados e fluentes na língua para a melhor tradução e precisão possível!*

Como executar o EXOTIC na nuvem colaborativa do Google (Google Colab)

Siga este [link](https://docs.google.com/document/d/1uZw1WLcTVvWEZlnPja-ObNeo0QK_9qNj4gbvHTMigyw/edit?usp=sharing) para acessar as instruções.



Abaixo, há uma lista com nossos colaboradores:

1. [Kaio Duarte Costa](https://github.com/kaiodcosta)
